@@ -7,8 +7,9 @@ import os, json, wget
 import numpy as np
 import pandas as pd
 
-def setup_terrier():
-    if not os.path.isfile("terrier-assemblies-5.1-jar-with-dependencies.jar"):
+def setup_terrier(file_path):
+    file_path = os.path.dirname(os.path.abspath(__file__))
+    if not os.path.isfile(os.path.join(file_path,"terrier-assemblies-5.1-jar-with-dependencies.jar")):
         print('JAR file not found, downloading')
         url = 'https://repo.maven.apache.org/maven2/org/terrier/terrier-assemblies/5.1/terrier-assemblies-5.1-jar-with-dependencies.jar'
         wget.download(url, '.')
@@ -18,12 +19,13 @@ def setup_terrier():
     # from utils import Utils
     # from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
 
-setup_terrier()
+file_path = os.path.dirname(os.path.abspath(__file__))
+setup_terrier(file_path)
 import jnius_config
-jnius_config.add_classpath("./terrier-assemblies-5.1-jar-with-dependencies.jar")
+jnius_config.add_classpath(os.path.join(file_path,"terrier-assemblies-5.1-jar-with-dependencies.jar"))
 from jnius import autoclass, cast
-from utils import Utils
-from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
+from utils import *
+from batchretrieve import *
 
 if __name__ == "__main__":
     JIR = autoclass('org.terrier.querying.IndexRef')
